@@ -17,12 +17,12 @@ infile("standard.dat", " ")
       output();
   }
 
-title("Means of y. Error bars are 95% confidence for means");
+title("Means of y\nError bars are 95% confidence for means");
   {
     pict *p;
 
     sort("mtest", "part x", "");
-    p = plotmeans("mtest.srt", "y", "x", "SEM 1.96", "part", 2);
+    p = plotmeans("mtest.srt", "y", "x", "SEM 1.96", "==", "part", 2);
 /* p[0] and p[1] are error bars and means as points for group 1 */
     strcpy(p[1].pict_type, "TRIA");
 /* p[2] and p[3] are error bars and means as points for group 2 */
