@@ -20,6 +20,7 @@
  *  along with Dap.  If not, see <http://www.gnu.org/licenses/>.
  */
 
+
 #include <sys/types.h>
 #include <time.h>
 #include <sys/stat.h>
@@ -29,6 +30,8 @@
 #include "dap_make.h"
 #include "externs.h"
 
+
+
 /* dataobs structures contain the names and values of the variables.  
  * Also contain number of variables, etc.: see dap_make.h.  
  */
@@ -543,7 +546,8 @@ int dap_arrnum(char vname[], int *dim)
   return -1;
 }
 
-static int getline(DFILE *fp, char *line)
+
+static int dap_getline(DFILE *fp, char *line)
 {
   int l;
   int c;
@@ -569,7 +573,7 @@ static int getline(DFILE *fp, char *line)
 	  else
 	    {
 	      line[l] = '\0';
-	      fprintf(dap_err, "(getline) line too long:\n%s\n", line);
+	      fprintf(dap_err, "(dap_getline) line too long:\n%s\n", line);
 	      exit(1);
 	    }
 	}
@@ -589,7 +593,7 @@ static int getline(DFILE *fp, char *line)
       line[l] = '\0';
       break;
     default:
-      fprintf(dap_err, "(getline) bad infile type: %d\n", intype);
+      fprintf(dap_err, "(dap_getline) bad infile type: %d\n", intype);
       exit(1);
     }
   if (!l && c == EOF)
@@ -773,7 +777,7 @@ void skip(int nlines)
 		  dap_ono);
 	  exit(1);
 	}
-      if (getline(dap_in[dap_ono], line) < 0)
+      if (dap_getline(dap_in[dap_ono], line) < 0)
 	eof[dap_ono] = 1;
       lineno[dap_ono]++;
     }
@@ -789,7 +793,7 @@ int step()
   int l;
   int i;
   int iv;
-  int nread;	/* number of chars read by getline */
+  int nread;	/* number of chars read by dap_getline */
 
   if (!stepinit)
     {
@@ -823,7 +827,7 @@ int step()
 	}
     }
   dap_prev[dap_ono].do_valid = dap_obs[dap_ono].do_valid;
-  if ((nread = getline(dap_in[dap_ono], line)) <= 0)
+  if ((nread = dap_getline(dap_in[dap_ono], line)) <= 0)
     {
       eof[dap_ono] = 1;
       dap_obs[dap_ono].do_valid = 0;
@@ -2069,7 +2073,7 @@ void inset(char *fname)
     }
   intype = DSET;
   dap_delim = '\0';
-  if (getline(dap_in[dap_ono], varspec) < 0)
+  if (dap_getline(dap_in[dap_ono], varspec) < 0)
     {
       fprintf(dap_err, "(inset) data set empty: %s\n", fname);
       exit(1);
