@@ -20,6 +20,8 @@
 
 #include <stdio.h>
 #include "sbs.h"
+#include <stdlib.h>
+#include <string.h>
 
 /* step types */
 #define DATA 1
